@@ -19,24 +19,11 @@ end
 require "bundler/setup"
 require "async/io"
 
-# This is useful for specs, but I hesitate to monkey patch a core class in the library itself.
-class Addrinfo
-	def == other
-		self.to_s == other.to_s
-	end
-	
-	def != other
-		self.to_s != other.to_s
-	end
-	
-	def <=> other
-		self.to_s <=> other.to_s
-	end
-end
-
 # Shared rspec helpers:
 require "async/rspec"
 
+require_relative 'addrinfo'
+
 RSpec.configure do |config|
 	# Enable flags like --only-failures and --next-failure
 	config.example_status_persistence_file_path = ".rspec_status"
